@@ -14,8 +14,6 @@ describe 'ovn::controller' do
       :mac_table_size              => 20000,
       :ovn_remote_probe_interval   => 30000,
       :ovn_openflow_probe_interval => 8,
-      :ovn_chassis_mac_map         => ['physnet1:aa:bb:cc:dd:ee:ff',
-                                       'physnet2:bb:aa:cc:dd:ee:ff']
     }
   end
 
@@ -74,10 +72,6 @@ describe 'ovn::controller' do
       is_expected.to contain_vs_config('external_ids:ovn-openflow-probe-interval').with(
         :value   => params[:ovn_openflow_probe_interval],
       )
-
-      is_expected.to contain_vs_config('external_ids:ovn-chassis-mac-mappings').with(
-        :value    => 'physnet1:aa:bb:cc:dd:ee:ff,physnet2:bb:aa:cc:dd:ee:ff',
-      )
     end
 
     it 'configures bridge mappings' do
@@ -95,22 +89,6 @@ describe 'ovn::controller' do
         :require => 'Service[openvswitch]'
       )
     end
-
-    context 'when ovn_chassis_mac_map is a hash' do
-      before :each do
-        params.merge!({
-          :ovn_chassis_mac_map => {
-            'physnet1' => 'aa:bb:cc:dd:ee:ff',
-            'physnet2' => 'bb:aa:cc:dd:ee:ff' }
-        })
-      end
-
-      it 'configures ovsdb' do
-        is_expected.to contain_vs_config('external_ids:ovn-chassis-mac-mappings').with(
-          :value    => 'physnet1:aa:bb:cc:dd:ee:ff,physnet2:bb:aa:cc:dd:ee:ff',
-        )
-      end
-    end
   end
 
   on_supported_os({
@@ -133,13 +111,13 @@ describe 'ovn::controller' do
           }
         end
         it_behaves_like 'ovn controller'
-      when 'Redhat'
+      when 'RedHat'
         let :platform_params do
           {
             :ovn_controller_package_name    => 'openvswitch-ovn-host',
             :ovn_controller_service_name    => 'ovn-controller',
             :ovn_controller_service_status  => true,
-            :ovn_controller_service_pattern => 'undef'
+            :ovn_controller_service_pattern => nil
           }
         end
         it_behaves_like 'ovn controller'
